#!/bin/bash

# Create new OSD and internally keep track of metrics required for deployment and activation.  This
# script should be called in a jinja2 for loop in salt using the hdd and journal names in the pillar
# as variables.  See pillar/apps/ceph/cluster/storage-node-v1-mapping.sls

## Things this script DOES NOT do:
## 1. Include admin keyring or conf file
## This script should be for OSD bootstrapping only

## Check if mon is listening/active
nc -z 10.10.6.0 6789

if [ $? -eq 1 ]
  then
    echo 'No active monitor detected...try again later'
    exit
fi

## Check for existence of active OSD data
is_active="$(vgdisplay --verbose | grep {{ disk }})"

if [ "$is_active" != "" ]
  then
    echo 'Backing device already active...exiting'
    echo $is_active
    exit
fi

osd_id="$(ceph osd create)"
ceph-volume lvm prepare --bluestore --data {{ disk }} --block.db {{ rocksdbDev }} --osd-id $osd_id
ceph osd crush add osd.$osd_id 1.0 host={{ hostname }}
ceph auth add osd.$osd_id osd 'allow *' mon 'allow profile osd' -i /var/lib/ceph/osd/{{ cluster }}-$osd_id/keyring
osd_fsid="$(cat /var/lib/ceph/osd/{{ cluster }}-$osd_id/fsid)"
ceph-volume lvm activate $osd_id $osd_fsid
