include: 
  - /apps/ceph/install-ceph
  - /apps/ceph/conf-file
  - /apps/ceph/admin-keyring

/tmp/ceph.mon.keyring:
  file.managed:
    - contents_pillar: ceph-mon-keyring
    - mode: 600
    - user: root
    - group: root

/var/lib/ceph/bootstrap-osd/ceph.keyring:
  file.managed:
    - contents_pillar: ceph-osd-bootstrap-keyring

ceph-authtool /tmp/ceph.mon.keyring --import-keyring /var/lib/ceph/bootstrap-osd/ceph.keyring:
  cmd.run

monmaptool --create --generate --clobber -c /etc/ceph/ceph.conf /tmp/monmap:
  cmd.run:
    - prereq: 
      - ceph-mon --cluster ceph --mkfs -i {{ grains['host'] }} --monmap /tmp/monmap --keyring /tmp/ceph.mon.keyring
  
mkdir -p /var/lib/ceph/mon/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}:
  cmd.run:
    - onlyif: 'test ! -e /var/lib/ceph/mon/{{ grains['host'] }}-{{ grains['ipv4'][0] }}'
    - requires: monmaptool --generate --clobber /tmp/monmap
  
ceph-mon --cluster {{ pillar['configuration']['cluster'] }} --mkfs -i {{ grains['host'] }} --monmap /tmp/monmap --keyring /tmp/ceph.mon.keyring:
  cmd.run:
    - requires:
      - /var/lib/ceph/mon/ceph-{{ grains['host'] }}

/var/lib/ceph/mon/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}:
  file.directory:
    - user: ceph
    - group: ceph
    - recurse:
      - user
      - group
    - requires: ceph-mon --cluster {{ pillar['configuration']['cluster'] }} --mkfs -i {{ grains['host'] }} --monmap /tmp/monmap --keyring /tmp/ceph.mon.keyring

/var/lib/ceph/mon/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}/done:
  file.managed:
    - requires:
      - /var/lib/ceph/mon/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}

ceph-mon@{{ grains['host'] }}:
  service.running:
    - watch:
      - sls: /apps/ceph/conf-file


/var/lib/ceph/mgr/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}:
  file.directory:
    - user: ceph
    - group: ceph

ceph-authtool --create-keyring /var/lib/ceph/mgr/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}/keyring --gen-key -n mgr.{{ grains['host'] }} --cap mon 'allow profile mgr' --cap osd 'allow *' --cap mds 'allow *':
  cmd.run:
    - requires:
      - /var/lib/ceph/mgr/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}

ceph auth import -i /var/lib/ceph/mgr/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}/keyring:
  cmd.run:
    - requires:
      - ceph-authtool --create-keyring /var/lib/ceph/mgr/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}/keyring --gen-key -n mgr.{{ grains['host'] }} --cap mon 'allow profile mgr' --cap osd 'allow *' --cap mds 'allow *'

ceph-mgr -i {{ grains['host'] }}:
  cmd.run:
    - requires:
      - ceph auth import -i /var/lib/ceph/mgr/{{ pillar['configuration']['cluster'] }}-{{ grains['host'] }}/keyring

/etc/ceph/volumes-keyring:
  file.managed:
    - contents_pillar: ceph-client-volumes-keyring

ceph auth add client.volumes mon 'allow r' osd 'allow class-read object_prefix rbd_children, allow rwx pool=volumes, allow rx pool=images' -i /etc/ceph/volumes-keyring:
  cmd.run:
    - requires:
      - /etc/ceph/volumes-keyring

/etc/ceph/images-keyring:
  file.managed:
    - contents_pillar: ceph-client-images-keyring

ceph auth add client.images mon 'allow r' osd 'allow class-read object_prefix rdb_children, allow rwx pool=images' -i /etc/ceph/images-keyring:
  cmd.run:
    - requires:
      - /etc/ceph/images-keyring

/etc/ceph/nova-keyring:
  file.managed:
    - contents_pillar: ceph-client-nova-keyring

ceph auth add client.nova mon 'allow r' osd 'allow class-read object_prefix rbd_children, allow rwx pool=vms, allow rx pool=images' -i /etc/ceph/nova-keyring:
  cmd.run:
    - requires:
      - /etc/ceph/nova-keyring

/etc/ceph/radosgw-0-keyring:
  file.managed:
    - contents_pillar: ceph-client-radosgw-0-keyring

ceph auth add client.radosgw.radosgw-0 osd 'allow rwx' mon 'allow rwx' -i /etc/ceph/radosgw-0-keyring:
  cmd.run:
    - requires:
      - /etc/ceph/radosgw-0-keyring
