include: 
  - /apps/ceph/install-ceph
  - /apps/ceph/conf-file
  - /apps/ceph/admin-keyring

ceph osd crush add-bucket {{ grains['host'] }} host:
  cmd.run

ceph osd crush move {{ grains['host'] }} root=default:
  cmd.run

/var/lib/ceph/bootstrap-osd/ceph.keyring:
  file.managed:
    - contents_pillar: ceph-osd-bootstrap-keyring

initialize_rocksdb:
  cmd.script:
    - source: salt://apps/ceph/files/init-rocksdb-device.sh
    - source_hash: salt://apps/ceph/files/hash

{% for disk, rocksdbDev in pillar.get('storage-node-v1-mapping', {}).items() %}

{{ disk }}_prep_script:
  cmd.script:
    - source: salt://apps/ceph/files/osd-bootstrap.sh
    - template: jinja
    - defaults:
        cluster: {{ pillar['configuration']['cluster'] }}
        disk: {{ disk }}
        hostname: {{ grains['host'] }}
        rocksdbDev: {{ pillar['storage-node-v1-mapping'][disk]['rocksdbDev'] }}
    - requires:
      - initialize_rocksdb
      - /var/lib/ceph/bootstrap-osd/ceph.keyring
    - onlyif: 
      - is_present=$(if grep -rnq {{ disk }} /proc/mounts;then echo 1;else echo 0;fi) && test $is_present -eq 0

{{ pillar['storage-node-v1-mapping'][disk]['rocksdbDev'] }}_permissions:
  file.managed:
    - name: {{ pillar['storage-node-v1-mapping'][disk]['rocksdbDev'] }}
    - user: ceph
    - group: ceph

{% endfor %}

ceph-osd.target:
  service.running:
    - watch:
      - sls: /apps/ceph/conf-file

