include:
  - /apps/openstack/magnum/install-magnum

make_magnum_service:
  cmd.script:
    - source: salt://apps/openstack/magnum/files/mkservice.sh
    - source_hash: salt://apps/openstack/magnum/files/hash
    - template: jinja
    - defaults:
        os_password: {{ pillar['openstack_admin_pass'] }}
        os_username: {{ pillar['admin_openrc']['OS_USERNAME'] }}
        os_project_name: {{ pillar['admin_openrc']['OS_PROJECT_NAME'] }}
        os_user_domain_name: {{ pillar['admin_openrc']['OS_USER_DOMAIN_NAME'] }}
        os_project_domain_name: {{ pillar['admin_openrc']['OS_PROJECT_DOMAIN_NAME'] }}
        os_identity_api_version: {{ pillar['admin_openrc']['OS_IDENTITY_API_VERSION'] }}
        os_auth_url: {{ pillar['keystone_configuration']['internal_endpoint']['protocol'] }}{{ pillar['keystone_configuration']['internal_endpoint']['url'] }}{{ pillar['keystone_configuration']['internal_endpoint']['port'] }}{{ pillar['keystone_configuration']['internal_endpoint']['path'] }}
        magnum_service_password: {{ pillar['magnum_service_password'] }}
        magnum_public_endpoint: {{ pillar['magnum_configuration']['public_endpoint']['protocol'] }}{{ pillar['magnum_configuration']['public_endpoint']['url'] }}{{ pillar['magnum_configuration']['public_endpoint']['port'] }}{{ pillar['magnum_configuration']['public_endpoint']['path'] }}
        magnum_internal_endpoint: {{ pillar['magnum_configuration']['internal_endpoint']['protocol'] }}{{ pillar['magnum_configuration']['internal_endpoint']['url'] }}{{ pillar['magnum_configuration']['internal_endpoint']['port'] }}{{ pillar['magnum_configuration']['internal_endpoint']['path'] }}
        magnum_admin_endpoint: {{ pillar['magnum_configuration']['admin_endpoint']['protocol'] }}{{ pillar['magnum_configuration']['admin_endpoint']['url'] }}{{ pillar['magnum_configuration']['admin_endpoint']['port'] }}{{ pillar['magnum_configuration']['admin_endpoint']['path'] }}
    - requires:
      - /apps/openstack/magnum/install-magnum

/etc/magnum/magnum.conf:
  file.managed:
    - source: salt://apps/openstack/magnum/files/magnum.conf
    - source_hash: salt://apps/openstack/magnum/files/hash
    - template: jinja
    - defaults:
        transport_url: transport_url = rabbit://openstack:{{ pillar['rmq_openstack_password'] }}@10.10.6.230
        sql_connection_string: 'connection = mysql+pymysql://magnum:{{ pillar['magnum_password'] }}@{{ pillar ['mysql_configuration']['address'] }}/magnum'
        auth_strategy: auth_strategy = keystone
        auth_uri: auth_uri = {{ pillar['keystone_configuration']['public_endpoint']['protocol'] }}{{ pillar['keystone_configuration']['public_endpoint']['url'] }}{{ pillar['keystone_configuration']['public_endpoint']['port'] }}{{ pillar['keystone_configuration']['public_endpoint']['path'] }}
        auth_url: auth_url = {{ pillar['keystone_configuration']['internal_endpoint']['protocol'] }}{{ pillar['keystone_configuration']['internal_endpoint']['url'] }}{{ pillar['keystone_configuration']['internal_endpoint']['port'] }}{{ pillar['keystone_configuration']['internal_endpoint']['path'] }}
        memcached_servers: memcached_servers = {{ pillar['memcached_servers']['address'] }}:11211
        auth_type: auth_type = password
        host: host = {{ grains['ipv4'][0] }}
        project_domain_name: project_domain_name = {{ pillar['magnum_openrc']['OS_PROJECT_DOMAIN_NAME'] }}
        user_domain_name: user_domain_name = {{ pillar['magnum_openrc']['OS_USER_DOMAIN_NAME'] }}
        project_name: project_name = {{ pillar['magnum_openrc']['OS_PROJECT_NAME'] }}
        username: username = {{ pillar['magnum_openrc']['OS_USERNAME'] }}
        password: password = {{ pillar['magnum_service_password'] }}
        trustee_domain_name: trustee_domain_name = magnum
        trustee_domain_admin_name: trustee_domain_admin_name = magnum_domain_admin
        trustee_domain_admin_password: trustee_domain_admin_password = {{ pillar['magnum_service_password'] }}
        trustee_keystone_interface: trustee_keystone_interface = internal

/bin/sh -c "magnum-db-manage upgrade" magnum:
  cmd.run

magnum_api_service:
  service.running:
    - name: magnum-api
    - watch:
      - file: /etc/magnum/magnum.conf

magnum_conductor_service:
  service.running:
    - name: magnum-conductor
    - watch:
      - file: /etc/magnum/magnum.conf
